Config class

Constructors

Config({required String applicationId, required String clientId, required String clientSecret, String version = ""})
Config.fromJson(Map<String, String> json)
factory

Properties

application ↔ String
getter/setter pair
applicationId → String
final
category ↔ String?
getter/setter pair
clientId → String
final
clientSecret → String
final
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int
getter/setter pair
offset ↔ int
getter/setter pair
orderBy ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server ↔ String?
getter/setter pair
static ↔ String?
getter/setter pair
token ↔ String?
getter/setter pair
version ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited