TransactionProfileModel class

Constructors

TransactionProfileModel({String? id, String? identifier, String? currency, bool? isBlocked, int? minTransactionAmount, int? maxTransactionAmount, int? minTransactionVirtualValue, int? maxTransactionVirtualValue, int? stepAmount, int? stepVirtualValue, Map<String, dynamic>? transactionTypesAmount, Map<String, dynamic>? transactionTypesCategories, Map<String, dynamic>? transactionTypesVirtualValue, Map<String, dynamic>? additionalData, String? importHash, String? createdAt, String? updatedAt, String? deletedAt, String? tenantId, String? createdById, String? updatedById})
TransactionProfileModel.fromJson(Map<String, dynamic> json)
factory

Properties

additionalData ↔ Map<String, dynamic>?
getter/setter pair
createdAt ↔ String?
getter/setter pair
createdById ↔ String?
getter/setter pair
currency ↔ String?
getter/setter pair
deletedAt ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
identifier ↔ String?
getter/setter pair
importHash ↔ String?
getter/setter pair
isBlocked ↔ bool?
getter/setter pair
maxTransactionAmount ↔ int?
getter/setter pair
maxTransactionVirtualValue ↔ int?
getter/setter pair
minTransactionAmount ↔ int?
getter/setter pair
minTransactionVirtualValue ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepAmount ↔ int?
getter/setter pair
stepVirtualValue ↔ int?
getter/setter pair
tenantId ↔ String?
getter/setter pair
transactionTypesAmount ↔ Map<String, dynamic>?
getter/setter pair
transactionTypesCategories ↔ Map<String, dynamic>?
getter/setter pair
transactionTypesVirtualValue ↔ Map<String, dynamic>?
getter/setter pair
updatedAt ↔ String?
getter/setter pair
updatedById ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited