TransactionReportListModel class

Constructors

TransactionReportListModel({int? count, int? limit, int? offset, List<TransactionReportModel>? rows})
TransactionReportListModel.fromJson(Map<String, dynamic> json)

Properties

count ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int?
getter/setter pair
offset ↔ int?
getter/setter pair
rows ↔ List<TransactionReportModel>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited